@@ -35,6 +35,8 @@ class QUrl;
 class KToolInvocationPrivate;
 
 /**
+ * @class KToolInvocation ktoolinvocation.h <KToolInvocation>
+ *
  * KToolInvocation: for starting other programs
  *
  * @section desktopfiles Desktop files for startServiceBy
@@ -91,7 +93,7 @@ public Q_SLOTS:
      * @deprecated since 5.0, use QDesktopServices::openUrl(mailtoURL),
      * using QUrl::setPath(address) and a query item of "subject" for the subject.
      */
-    static void invokeMailer(const QString &address, const QString &subject,
+    KSERVICE_DEPRECATED static void invokeMailer(const QString &address, const QString &subject,
                              const QByteArray &startup_id = QByteArray());
 
     /**
@@ -104,7 +106,7 @@ public Q_SLOTS:
      *           The default is false; do not honor requests for attachments.
      * @deprecated since 5.0, use QDesktopServices::openUrl(mailtoURL)
      */
-    static void invokeMailer(const QUrl &mailtoURL, const QByteArray &startup_id = QByteArray(),
+    KSERVICE_DEPRECATED static void invokeMailer(const QUrl &mailtoURL, const QByteArray &startup_id = QByteArray(),
                              bool allowAttachments = false);
 
     /**
@@ -143,8 +145,8 @@ public Q_SLOTS:
      *           "" ( empty string ) is the default
      * @deprecated since 5.0, use QDesktopServices::openUrl(url)
      */
-    static void invokeBrowser(const QString &url,
-                              const QByteArray &startup_id = QByteArray());
+    KSERVICE_DEPRECATED static void invokeBrowser(const QString &url,
+                                                  const QByteArray &startup_id = QByteArray());
 
     /**
      * Invokes the standard terminal application.
@@ -185,7 +187,7 @@ public:
      */
 #ifndef KSERVICE_NO_DEPRECATED
     KSERVICE_DEPRECATED static int startServiceByName(const QString &_name, const QString &URL,
-            QString *error = 0, QString *serviceName = 0, int *pid = 0,
+            QString *error = nullptr, QString *serviceName = nullptr, int *pid = nullptr,
             const QByteArray &startup_id = QByteArray(), bool noWait = false);
 #endif
 
@@ -212,7 +214,7 @@ public:
      */
 #ifndef KSERVICE_NO_DEPRECATED
     KSERVICE_DEPRECATED static int startServiceByName(const QString &_name, const QStringList &URLs = QStringList(),
-            QString *error = 0, QString *serviceName = 0, int *pid = 0,
+            QString *error = nullptr, QString *serviceName = nullptr, int *pid = nullptr,
             const QByteArray &startup_id = QByteArray(), bool noWait = false);
 #endif
 
@@ -237,11 +239,11 @@ public:
      * @return an error code indicating success (== 0) or failure (> 0).
      *
      * @deprecated since 5.0 use QDBusConnectionInterface::startService("org.kde.serviceName"),
-     *   to start a unique application in order to make dbus calls to it (after ensuring that
-     *   it installs a dbus org.kde.serviceName.service file). Otherwise just use QProcess or KRun.
+     *   to start a unique application in order to make D-Bus calls to it (after ensuring that
+     *   it installs a D-Bus org.kde.serviceName.service file). Otherwise just use QProcess or KRun.
      */
     static int startServiceByDesktopPath(const QString &_name, const QString &URL,
-                                         QString *error = 0, QString *serviceName = 0, int *pid = 0,
+                                         QString *error = nullptr, QString *serviceName = nullptr, int *pid = nullptr,
                                          const QByteArray &startup_id = QByteArray(), bool noWait = false);
 
     /**
@@ -263,11 +265,11 @@ public:
      * @param noWait if set, the function does not wait till the service is running.
      * @return an error code indicating success (== 0) or failure (> 0).
      * @deprecated since 5.0 use QDBusConnectionInterface::startService("org.kde.serviceName"),
-     *   to start a unique application in order to make dbus calls to it (after ensuring that
-     *   it installs a dbus org.kde.serviceName.service file). Otherwise just use QProcess or KRun.
+     *   to start a unique application in order to make D-Bus calls to it (after ensuring that
+     *   it installs a D-Bus org.kde.serviceName.service file). Otherwise just use QProcess or KRun.
      */
     static int startServiceByDesktopPath(const QString &_name, const QStringList &URLs = QStringList(),
-                                         QString *error = 0, QString *serviceName = 0, int *pid = 0,
+                                         QString *error = nullptr, QString *serviceName = nullptr, int *pid = nullptr,
                                          const QByteArray &startup_id = QByteArray(), bool noWait = false);
 
     /**
@@ -290,11 +292,11 @@ public:
      * @param noWait if set, the function does not wait till the service is running.
      * @return an error code indicating success (== 0) or failure (> 0).
      * @deprecated since 5.0 use QDBusConnectionInterface::startService("org.kde.serviceName"),
-     *   to start a unique application in order to make dbus calls to it (after ensuring that
-     *   it installs a dbus org.kde.serviceName.service file). Otherwise just use QProcess or KRun.
+     *   to start a unique application in order to make D-Bus calls to it (after ensuring that
+     *   it installs a D-Bus org.kde.serviceName.service file). Otherwise just use QProcess or KRun.
      */
     static int startServiceByDesktopName(const QString &_name, const QString &URL,
-                                         QString *error = 0, QString *serviceName = 0, int *pid = 0,
+                                         QString *error = nullptr, QString *serviceName = nullptr, int *pid = nullptr,
                                          const QByteArray &startup_id = QByteArray(), bool noWait = false);
 
     /**
@@ -317,11 +319,11 @@ public:
      * @param noWait if set, the function does not wait till the service is running.
      * @return an error code indicating success (== 0) or failure (> 0).
      * @deprecated since 5.0 use QDBusConnectionInterface::startService("org.kde.serviceName"),
-     *   to start a unique application in order to make dbus calls to it (after ensuring that
-     *   it installs a dbus org.kde.serviceName.service file). Otherwise just use QProcess or KRun.
+     *   to start a unique application in order to make D-Bus calls to it (after ensuring that
+     *   it installs a D-Bus org.kde.serviceName.service file). Otherwise just use QProcess or KRun.
      */
     static int startServiceByDesktopName(const QString &_name, const QStringList &URLs = QStringList(),
-                                         QString *error = 0, QString *serviceName = 0, int *pid = 0,
+                                         QString *error = nullptr, QString *serviceName = nullptr, int *pid = nullptr,
                                          const QByteArray &startup_id = QByteArray(), bool noWait = false);
 
     /**
@@ -342,7 +344,7 @@ public:
      * @return an error code indicating success (== 0) or failure (> 0).
      */
     static int kdeinitExec(const QString &name, const QStringList &args = QStringList(),
-                           QString *error = 0, int *pid = 0, const QByteArray &startup_id = QByteArray());
+                           QString *error = nullptr, int *pid = nullptr, const QByteArray &startup_id = QByteArray());
 
     /**
      * Starts a program via kdeinit and wait for it to finish.
@@ -362,7 +364,7 @@ public:
      * @return an error code indicating success (== 0) or failure (> 0).
      */
     static int kdeinitExecWait(const QString &name, const QStringList &args = QStringList(),
-                               QString *error = 0, int *pid = 0, const QByteArray &startup_id = QByteArray());
+                               QString *error = nullptr, int *pid = nullptr, const QByteArray &startup_id = QByteArray());
 
     /**
      * Ensures that kdeinit5 and klauncher are running.
@@ -382,7 +384,7 @@ private:
                              QString *error, QString *serviceName, int *pid,
                              const QByteArray &startup_id, bool noWait,
                              const QString &workdir = QString());
-    static bool isMainThreadActive(QString *error = 0);
+    static bool isMainThreadActive(QString *error = nullptr);
 
     KToolInvocationPrivate *const d;
     friend class KToolInvocationSingleton;
